@@ -1,10 +1,10 @@
 """
     created 14.20.2020 by Jens Diemer <opensource@jensdiemer.de>
-    :copyleft: 2020 by the PyInventory team, see AUTHORS for more details.
+    :copyleft: 2020-2021 by the PyInventory team, see AUTHORS for more details.
     :license: GNU GPL v3 or above, see LICENSE for more details.
 """
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 
 # https://docs.djangoproject.com/en/2.0/ref/applications/#configuring-applications-ref
 default_app_config = "inventory.apps.InventoryConfig"
